<a id="mypy-boto3-comprehend"></a>

# mypy-boto3-comprehend

[![PyPI - mypy-boto3-comprehend](https://img.shields.io/pypi/v/mypy-boto3-comprehend.svg?color=blue)](https://pypi.org/project/mypy-boto3-comprehend)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-comprehend.svg?color=blue)](https://pypi.org/project/mypy-boto3-comprehend)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-comprehend?color=blue)](https://pypistats.org/packages/mypy-boto3-comprehend)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Comprehend 1.18.1](https://boto3.amazonaws.com/v1/documentation/api/1.18.1/reference/services/comprehend.html#Comprehend)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 5.0.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-comprehend docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-comprehend](#mypy-boto3-comprehend)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Comprehend` service.

```bash
python -m pip install boto3-stubs[comprehend]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[comprehend]` in your environment:
  `python -m pip install 'boto3-stubs[comprehend]'`

Both type checking and auto-complete should work for `Comprehend` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[comprehend]` in your environment:
  `python -m pip install 'boto3-stubs[comprehend]'`

Both type checking and auto-complete should work for `Comprehend` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[comprehend]` in your environment:
  `python -m pip install 'boto3-stubs[comprehend]'`
- Run `mypy` as usual

Type checking should work for `Comprehend` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[comprehend]` in your environment:
  `python -m pip install 'boto3-stubs[comprehend]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Comprehend` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ComprehendClient` provides annotations for `boto3.client("comprehend")`.

```python
import boto3

from mypy_boto3_comprehend import ComprehendClient

client: ComprehendClient = boto3.client("comprehend")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ComprehendClient = session.client("comprehend")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_comprehend.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_comprehend import ComprehendClient
from mypy_boto3_comprehend.paginator import (
    ListDocumentClassificationJobsPaginator,
    ListDocumentClassifiersPaginator,
    ListDominantLanguageDetectionJobsPaginator,
    ListEntitiesDetectionJobsPaginator,
    ListEntityRecognizersPaginator,
    ListKeyPhrasesDetectionJobsPaginator,
    ListSentimentDetectionJobsPaginator,
    ListTopicsDetectionJobsPaginator,
)

client: ComprehendClient = boto3.client("comprehend")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_document_classification_jobs_paginator: ListDocumentClassificationJobsPaginator = client.get_paginator("list_document_classification_jobs")
list_document_classifiers_paginator: ListDocumentClassifiersPaginator = client.get_paginator("list_document_classifiers")
list_dominant_language_detection_jobs_paginator: ListDominantLanguageDetectionJobsPaginator = client.get_paginator("list_dominant_language_detection_jobs")
list_entities_detection_jobs_paginator: ListEntitiesDetectionJobsPaginator = client.get_paginator("list_entities_detection_jobs")
list_entity_recognizers_paginator: ListEntityRecognizersPaginator = client.get_paginator("list_entity_recognizers")
list_key_phrases_detection_jobs_paginator: ListKeyPhrasesDetectionJobsPaginator = client.get_paginator("list_key_phrases_detection_jobs")
list_sentiment_detection_jobs_paginator: ListSentimentDetectionJobsPaginator = client.get_paginator("list_sentiment_detection_jobs")
list_topics_detection_jobs_paginator: ListTopicsDetectionJobsPaginator = client.get_paginator("list_topics_detection_jobs")
```

<a id="literals"></a>

### Literals

`mypy_boto3_comprehend.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_comprehend.literals import (
    DocumentClassifierDataFormatType,
    DocumentClassifierModeType,
    EndpointStatusType,
    EntityRecognizerDataFormatType,
    EntityTypeType,
    InputFormatType,
    JobStatusType,
    LanguageCodeType,
    ListDocumentClassificationJobsPaginatorName,
    ListDocumentClassifiersPaginatorName,
    ListDominantLanguageDetectionJobsPaginatorName,
    ListEntitiesDetectionJobsPaginatorName,
    ListEntityRecognizersPaginatorName,
    ListKeyPhrasesDetectionJobsPaginatorName,
    ListSentimentDetectionJobsPaginatorName,
    ListTopicsDetectionJobsPaginatorName,
    ModelStatusType,
    PartOfSpeechTagTypeType,
    PiiEntitiesDetectionMaskModeType,
    PiiEntitiesDetectionModeType,
    PiiEntityTypeType,
    SentimentTypeType,
    SyntaxLanguageCodeType,
)

def check_value(value: DocumentClassifierDataFormatType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_comprehend.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_comprehend.type_defs import (
    AugmentedManifestsListItemTypeDef,
    BatchDetectDominantLanguageItemResultTypeDef,
    BatchDetectDominantLanguageRequestRequestTypeDef,
    BatchDetectDominantLanguageResponseTypeDef,
    BatchDetectEntitiesItemResultTypeDef,
    BatchDetectEntitiesRequestRequestTypeDef,
    BatchDetectEntitiesResponseTypeDef,
    BatchDetectKeyPhrasesItemResultTypeDef,
    BatchDetectKeyPhrasesRequestRequestTypeDef,
    BatchDetectKeyPhrasesResponseTypeDef,
    BatchDetectSentimentItemResultTypeDef,
    BatchDetectSentimentRequestRequestTypeDef,
    BatchDetectSentimentResponseTypeDef,
    BatchDetectSyntaxItemResultTypeDef,
    BatchDetectSyntaxRequestRequestTypeDef,
    BatchDetectSyntaxResponseTypeDef,
    BatchItemErrorTypeDef,
    ClassifierEvaluationMetricsTypeDef,
    ClassifierMetadataTypeDef,
    ClassifyDocumentRequestRequestTypeDef,
    ClassifyDocumentResponseTypeDef,
    ContainsPiiEntitiesRequestRequestTypeDef,
    ContainsPiiEntitiesResponseTypeDef,
    CreateDocumentClassifierRequestRequestTypeDef,
    CreateDocumentClassifierResponseTypeDef,
    CreateEndpointRequestRequestTypeDef,
    CreateEndpointResponseTypeDef,
    CreateEntityRecognizerRequestRequestTypeDef,
    CreateEntityRecognizerResponseTypeDef,
    DeleteDocumentClassifierRequestRequestTypeDef,
    DeleteEndpointRequestRequestTypeDef,
    DeleteEntityRecognizerRequestRequestTypeDef,
    DescribeDocumentClassificationJobRequestRequestTypeDef,
    DescribeDocumentClassificationJobResponseTypeDef,
    DescribeDocumentClassifierRequestRequestTypeDef,
    DescribeDocumentClassifierResponseTypeDef,
    DescribeDominantLanguageDetectionJobRequestRequestTypeDef,
    DescribeDominantLanguageDetectionJobResponseTypeDef,
    DescribeEndpointRequestRequestTypeDef,
    DescribeEndpointResponseTypeDef,
    DescribeEntitiesDetectionJobRequestRequestTypeDef,
    DescribeEntitiesDetectionJobResponseTypeDef,
    DescribeEntityRecognizerRequestRequestTypeDef,
    DescribeEntityRecognizerResponseTypeDef,
    DescribeEventsDetectionJobRequestRequestTypeDef,
    DescribeEventsDetectionJobResponseTypeDef,
    DescribeKeyPhrasesDetectionJobRequestRequestTypeDef,
    DescribeKeyPhrasesDetectionJobResponseTypeDef,
    DescribePiiEntitiesDetectionJobRequestRequestTypeDef,
    DescribePiiEntitiesDetectionJobResponseTypeDef,
    DescribeSentimentDetectionJobRequestRequestTypeDef,
    DescribeSentimentDetectionJobResponseTypeDef,
    DescribeTopicsDetectionJobRequestRequestTypeDef,
    DescribeTopicsDetectionJobResponseTypeDef,
    DetectDominantLanguageRequestRequestTypeDef,
    DetectDominantLanguageResponseTypeDef,
    DetectEntitiesRequestRequestTypeDef,
    DetectEntitiesResponseTypeDef,
    DetectKeyPhrasesRequestRequestTypeDef,
    DetectKeyPhrasesResponseTypeDef,
    DetectPiiEntitiesRequestRequestTypeDef,
    DetectPiiEntitiesResponseTypeDef,
    DetectSentimentRequestRequestTypeDef,
    DetectSentimentResponseTypeDef,
    DetectSyntaxRequestRequestTypeDef,
    DetectSyntaxResponseTypeDef,
    DocumentClassTypeDef,
    DocumentClassificationJobFilterTypeDef,
    DocumentClassificationJobPropertiesTypeDef,
    DocumentClassifierFilterTypeDef,
    DocumentClassifierInputDataConfigTypeDef,
    DocumentClassifierOutputDataConfigTypeDef,
    DocumentClassifierPropertiesTypeDef,
    DocumentLabelTypeDef,
    DominantLanguageDetectionJobFilterTypeDef,
    DominantLanguageDetectionJobPropertiesTypeDef,
    DominantLanguageTypeDef,
    EndpointFilterTypeDef,
    EndpointPropertiesTypeDef,
    EntitiesDetectionJobFilterTypeDef,
    EntitiesDetectionJobPropertiesTypeDef,
    EntityLabelTypeDef,
    EntityRecognizerAnnotationsTypeDef,
    EntityRecognizerDocumentsTypeDef,
    EntityRecognizerEntityListTypeDef,
    EntityRecognizerEvaluationMetricsTypeDef,
    EntityRecognizerFilterTypeDef,
    EntityRecognizerInputDataConfigTypeDef,
    EntityRecognizerMetadataEntityTypesListItemTypeDef,
    EntityRecognizerMetadataTypeDef,
    EntityRecognizerPropertiesTypeDef,
    EntityTypeDef,
    EntityTypesEvaluationMetricsTypeDef,
    EntityTypesListItemTypeDef,
    EventsDetectionJobFilterTypeDef,
    EventsDetectionJobPropertiesTypeDef,
    InputDataConfigTypeDef,
    KeyPhraseTypeDef,
    KeyPhrasesDetectionJobFilterTypeDef,
    KeyPhrasesDetectionJobPropertiesTypeDef,
    ListDocumentClassificationJobsRequestRequestTypeDef,
    ListDocumentClassificationJobsResponseTypeDef,
    ListDocumentClassifiersRequestRequestTypeDef,
    ListDocumentClassifiersResponseTypeDef,
    ListDominantLanguageDetectionJobsRequestRequestTypeDef,
    ListDominantLanguageDetectionJobsResponseTypeDef,
    ListEndpointsRequestRequestTypeDef,
    ListEndpointsResponseTypeDef,
    ListEntitiesDetectionJobsRequestRequestTypeDef,
    ListEntitiesDetectionJobsResponseTypeDef,
    ListEntityRecognizersRequestRequestTypeDef,
    ListEntityRecognizersResponseTypeDef,
    ListEventsDetectionJobsRequestRequestTypeDef,
    ListEventsDetectionJobsResponseTypeDef,
    ListKeyPhrasesDetectionJobsRequestRequestTypeDef,
    ListKeyPhrasesDetectionJobsResponseTypeDef,
    ListPiiEntitiesDetectionJobsRequestRequestTypeDef,
    ListPiiEntitiesDetectionJobsResponseTypeDef,
    ListSentimentDetectionJobsRequestRequestTypeDef,
    ListSentimentDetectionJobsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTopicsDetectionJobsRequestRequestTypeDef,
    ListTopicsDetectionJobsResponseTypeDef,
    OutputDataConfigTypeDef,
    PaginatorConfigTypeDef,
    PartOfSpeechTagTypeDef,
    PiiEntitiesDetectionJobFilterTypeDef,
    PiiEntitiesDetectionJobPropertiesTypeDef,
    PiiEntityTypeDef,
    PiiOutputDataConfigTypeDef,
    RedactionConfigTypeDef,
    ResponseMetadataTypeDef,
    SentimentDetectionJobFilterTypeDef,
    SentimentDetectionJobPropertiesTypeDef,
    SentimentScoreTypeDef,
    StartDocumentClassificationJobRequestRequestTypeDef,
    StartDocumentClassificationJobResponseTypeDef,
    StartDominantLanguageDetectionJobRequestRequestTypeDef,
    StartDominantLanguageDetectionJobResponseTypeDef,
    StartEntitiesDetectionJobRequestRequestTypeDef,
    StartEntitiesDetectionJobResponseTypeDef,
    StartEventsDetectionJobRequestRequestTypeDef,
    StartEventsDetectionJobResponseTypeDef,
    StartKeyPhrasesDetectionJobRequestRequestTypeDef,
    StartKeyPhrasesDetectionJobResponseTypeDef,
    StartPiiEntitiesDetectionJobRequestRequestTypeDef,
    StartPiiEntitiesDetectionJobResponseTypeDef,
    StartSentimentDetectionJobRequestRequestTypeDef,
    StartSentimentDetectionJobResponseTypeDef,
    StartTopicsDetectionJobRequestRequestTypeDef,
    StartTopicsDetectionJobResponseTypeDef,
    StopDominantLanguageDetectionJobRequestRequestTypeDef,
    StopDominantLanguageDetectionJobResponseTypeDef,
    StopEntitiesDetectionJobRequestRequestTypeDef,
    StopEntitiesDetectionJobResponseTypeDef,
    StopEventsDetectionJobRequestRequestTypeDef,
    StopEventsDetectionJobResponseTypeDef,
    StopKeyPhrasesDetectionJobRequestRequestTypeDef,
    StopKeyPhrasesDetectionJobResponseTypeDef,
    StopPiiEntitiesDetectionJobRequestRequestTypeDef,
    StopPiiEntitiesDetectionJobResponseTypeDef,
    StopSentimentDetectionJobRequestRequestTypeDef,
    StopSentimentDetectionJobResponseTypeDef,
    StopTrainingDocumentClassifierRequestRequestTypeDef,
    StopTrainingEntityRecognizerRequestRequestTypeDef,
    SyntaxTokenTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TopicsDetectionJobFilterTypeDef,
    TopicsDetectionJobPropertiesTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateEndpointRequestRequestTypeDef,
    VpcConfigTypeDef,
)

def get_structure() -> AugmentedManifestsListItemTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-comprehend` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-comprehend docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_comprehend/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
